Matter

Struct Matter 

pub struct Matter<T: Engine> {
    pub delimiter: String,
    pub close_delimiter: Option<String>,
    pub excerpt_delimiter: Option<String>,
    /* private fields */
}
Coupled with an Engine of choice, Matter stores delimiter(s) and handles parsing.

Fields

delimiter: Stringclose_delimiter: Option<String>excerpt_delimiter: Option<String>

Implementations

Source

impl<T: Engine> Matter<T>

pub fn new() -> Self

pub fn parse<D: DeserializeOwned>(&self, input: &str) -> Result<ParsedEntity<D>>

Runs parsing on the input. Uses the engine contained in self to parse any front matter detected.

Examples

Basic usage:

let matter: Matter<YAML> = Matter::new();
let input = "---\ntitle: Home\n---\nOther stuff";
let parsed_entity: ParsedEntity = matter.parse(input).unwrap();

assert_eq!(parsed_entity.content, "Other stuff");